pub fn image_to_pixmap(image: &ImageData) -> PixmapExpand description
A decoded image as a pixmap, composed the way a page draw would compose it: its mask applied, its matte removed, a stencil painted black.
For an image that is not on a page — a /Thumb, an embedded file — where
there is no graphics state to take a fill colour or a transfer function
from.